MODULE iniphyparam_mod
  IMPLICIT NONE
  PRIVATE

  REAL, PARAMETER :: perfect_gas_const = 8134.

  PUBLIC :: iniphyparam

CONTAINS
  
  SUBROUTINE iniphyparam(ngrid,nlayer, &
       &           punjours,              &
       &           pdayref,ptimestep,     &
       &           prad,pg,pr,pcpp)
    use getparam
    use dimphy
    USE mod_grid_phy_lmdz
    USE mod_phys_lmdz_para
    USE callkeys
    use comgeomfi
    USE geometry_mod, ONLY : longitude,latitude
    USE phys_const, ONLY : planet_rad,g,r,cpp,rcp,dtphys,unjours,mugaz
    USE planet, ONLY : coefir, coefvis
    USE astronomy
    USE turbulence, ONLY : lmixmin, emin_turb 
    USE surface
    USE read_param_mod
    USE phyparam_plugins_lmdz

    IMPLICIT NONE
    
    !    ngrid                 Size of the horizontal grid.
    !                          All internal loops are performed on that grid.
    !    nlayer                Number of vertical layers.
    !    pdayref               Day of reference for the simulation
    !    firstcall             True at the first call
    !    lastcall              True at the last call
    !    pday                  Number of days counted from the North. Spring
    !                          equinox

    REAL prad,pg,pr,pcpp,punjours
    
    INTEGER ngrid, nlayer, pdayref
    
    REAL ptimestep
    
    print*,'INIPHYPARAM'
    
    read_paramr_plugin => read_paramr
    read_parami_plugin => read_parami
    read_paramb_plugin => read_paramb

    CALL init_comgeomfi(klon_omp, klev, longitude, latitude)
    
    IF (klon.NE.klon_omp) THEN
       PRINT*,'STOP in iniphyparam'
       PRINT*,'Probleme de dimensions :'
       PRINT*,'klon     = ',klon
       PRINT*,'klon_omp   = ',klon_omp
       STOP
    ENDIF
    
    IF (nlayer.NE.nlayermx) THEN
       PRINT*,'STOP in iniphyparam'
       PRINT*,'Probleme de dimensions :'
       PRINT*,'nlayer     = ',nlayer
       PRINT*,'nlayermx   = ',nlayermx
       STOP
    ENDIF
    
    IF (ngrid.NE.klon_glo) THEN
       PRINT*,'STOP in iniphyparam'
       PRINT*,'Probleme de dimensions :'
       PRINT*,'ngrid     = ',ngrid
       PRINT*,'ngridmax   = ',klon_glo
       STOP
    ENDIF
    
    print*,'Avant les getpar '
    CALL read_param('unjours', 86400., unjours,'unjours')
    CALL read_param('planet_rad',6.4e6,planet_rad,'planet_rad')
    CALL read_param('g',9.8           ,g,'g')
    CALL read_param('cpp',1004.       ,cpp,'cpp')
    CALL read_param('mugaz',28.       ,mugaz,'mugaz')
    CALL read_param('year_day',360.   ,year_day,'year_day')
    CALL read_param('periheli',150.   ,periheli,'periheli')
    CALL read_param('aphelie',150.    ,aphelie,'aphelie')
    CALL read_param('peri_day',0.     ,peri_day,'peri_day')
    CALL read_param('obliquit',23.    ,obliquit,'obliquit')
    CALL read_param('Cd_mer',.01      ,Cd_mer,'Cd_mer')
    CALL read_param('Cd_ter',.01      ,Cd_ter,'Cd_ter')
    CALL read_param('I_mer',30000.    ,I_mer,'I_mer')
    CALL read_param('I_ter',30000.    ,I_ter,'I_ter')
    CALL read_param('alb_ter',.112    ,alb_ter,'alb_ter')
    CALL read_param('alb_mer',.112    ,alb_mer,'alb_mer')
    CALL read_param('emi_mer',1.      ,emi_mer,'emi_mer')
    CALL read_param('emi_mer',1.      ,emi_mer,'emi_mer')
    CALL read_param('emin_turb',1.e-16 ,emin_turb,'emin_turb')
    CALL read_param('lmixmin',100.    ,lmixmin,'lmixmin')
    CALL read_param('coefvis',.99     ,coefvis,'coefvis')
    CALL read_param('coefir',.08      ,coefir,'coefir')
    
    CALL read_param('callrad',.true.,callrad,'appel rayonnemen')
    CALL read_param('calldifv',.true.,calldifv,'appel difv')
    CALL read_param('calladj',.true.,calladj,'appel adj')
    CALL read_param('callcond',.true.,callcond,'appel cond')
    CALL read_param('callsoil',.true.,callsoil,'appel soil')
    CALL read_param('season',.true.,season,'appel soil')
    CALL read_param('diurnal',.false.,diurnal,'appel soil')
    CALL read_param('lverbose',.true.,lverbose,'appel soil')
    CALL read_param('period_sort',1.,period_sort,'period sorties en jour')
    
    print*,'Activation de la physique:'
    print*,' Rayonnement ',callrad
    print*,' Diffusion verticale turbulente ', calldifv
    print*,' Ajustement convectif ',calladj
    print*,' Sol ',callsoil
    print*,' Cycle diurne ',diurnal
    
    !   choice of the frequency of the computation of radiations
    IF(diurnal) THEN
       iradia=NINT(punjours/(20.*ptimestep))
    ELSE
       iradia=NINT(punjours/(4.*ptimestep))
    ENDIF
    iradia=1
    PRINT*,'unjours',punjours
    PRINT*,'The radiative transfer is computed each ', &
         &   iradia,' physical time-step or each ', &
         &   iradia*ptimestep,' seconds'
    
    !-----------------------------------------------------------------------
    
    print*,'latitude0  ohe',latitude(1:3),latitude(klon_omp)
    print*,'OK17 AAA'
    
    prad=planet_rad
    pg=g
    r=perfect_gas_const/mugaz
    print*,'R=',r
    pr=r
    pcpp=cpp
    rcp=r/cpp
    dtphys=ptimestep
    punjours=unjours
    
  END SUBROUTINE iniphyparam
  
END MODULE iniphyparam_mod
